==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/zh_CN.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "文档",
"Can't create document" => "无法创建文档",
"You don't have permission to rename this document" => "您没有重命名该文档的权限",
"Directory saved successfully." => "目录保存成功。",
"An error occurred while changing directory." => "修改目录时发生了一个错误。",
"Saved" => "已保存",
"Format filter server is down or misconfigured" => "格式过滤服务器无法连接或配置错误",
"Conversion failed. Check log for details." => "转换失败，请检查日志了解详情。",
"Saving..." => "保存中...",
"Failed to load documents." => "载入文档失败",
"No documents were found. Upload or create a document to get started!" => "未找到任何文档。开始上传或者创建文档！",
"No connection to server. Trying to reconnect." => "无法连接到服务，正在尝试重新连接。",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "从编辑模式离开当前页面可能会导致数据丢失。建议改用“关闭”按钮。",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "打开文档失败，请检查此文档是否可以使用外部 ODT 编辑器打开。同时，此文档可能已经关闭分享或者已经被删除。",
"Save" => "保存",
"Loading documents..." => "载入文档...",
"'.' is an invalid file name." => "'.' 是一个无效的文件名。",
"File name cannot be empty." => "文件名不能为空。",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "无效名称，'\\', '/', '<', '>', ':', '\"', '|', '?' 和 '*' 不被允许使用。",
"Align Left" => "左对齐",
"Alignment" => "对齐",
"Align Right" => "右对齐",
"Annotate" => "注释",
"Background" => "背景",
"Bold" => "粗体",
"Bottom" => "底部",
"Cancel" => "取消",
"Center" => "居中",
"Clone" => "克隆",
"Clone this Style" => "复制此样式",
"Close" => "关闭",
"Color" => "颜色",
"Create" => "创建",
"Decrease Indent" => "减少缩进",
"Default Style" => "默认样式",
"Delete" => "删除",
"Family" => "字体族",
"Font" => "字体",
"Font Effects" => "字体效果",
"Format" => "格式",
"Increase Indent" => "增加缩进",
"Insert Image" => "插入图片",
"Invite Members" => "邀请用户",
"Italic" => "斜体",
"Justified" => "两端对齐",
"Justify" => "对齐",
"Left" => "左对齐",
"Loading" => "加载中",
"Members" => "成员",
"New Name:" => "新样式名称：",
"OK" => "确定",
"Open" => "打开",
"Options" => "选项",
"Paragraph..." => "段落....",
"Paragraph Styles" => "段落样式",
"Redo" => "重做",
"Right" => "右对齐",
"Size" => "大小",
"Spacing" => "边距",
"Strikethrough" => "删除线",
"Style" => "样式",
"Text" => "文本",
"Top" => "顶部",
"Underline" => "下划线",
"Undo" => "撤消",
"Unknown Author" => "未知作者",
"Edit" => "编辑",
"Share" => "共享",
"guest" => "访客",
"MS Word support (requires openOffice/libreOffice)" => "Microsoft Word 支持 (需要 openOffice/libreOffice)",
"Local" => "本地",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "此服务器已经安装 openOffice/libreOffice，config.php 中的 preview_libreoffice_path 指定了程序的路径",
"External" => "外部",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice 安装在一台运行有 Format Filter Server 的外部服务器上",
"Disabled" => "禁用",
"No MS Word support" => "无 MS Word 支持",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "服务器 URL",
"Apply and test" => "应用并测试",
"New document" => "新建文档",
"Upload (max. %s)" => "上传 (最大 %s)",
"Upload" => "上传",
"Save new documents to" => "保存新文档到",
"Wrong password. Please retry." => "密码错误，请重新尝试。",
"Password" => "密码",
"Guest %s" => "访客 %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "该链接已失效或不存在。详情请联系文件分享者。",
"Advanced feature-set" => "高级功能",
"(Unstable)" => "(非稳定)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-app-documents-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/zh_CN.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "文档",
"Can't create document" => "无法创建文档",
"You don't have permission to rename this document" => "您没有重命名该文档的权限",
"Directory saved successfully." => "目录保存成功。",
"An error occurred while changing directory." => "修改目录时发生了一个错误。",
"Saved" => "已保存",
"Format filter server is down or misconfigured" => "格式过滤服务器无法连接或配置错误",
"Conversion failed. Check log for details." => "转换失败，请检查日志了解详情。",
"Saving..." => "保存中...",
"Failed to load documents." => "载入文档失败",
"No documents were found. Upload or create a document to get started!" => "未找到任何文档。开始上传或者创建文档！",
"No connection to server. Trying to reconnect." => "无法连接到服务，正在尝试重新连接。",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "从编辑模式离开当前页面可能会导致数据丢失。建议改用“关闭”按钮。",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "打开文档失败，请检查此文档是否可以使用外部 ODT 编辑器打开。同时，此文档可能已经关闭分享或者已经被删除。",
"Save" => "保存",
"Loading documents..." => "载入文档...",
"'.' is an invalid file name." => "'.' 是一个无效的文件名。",
"File name cannot be empty." => "文件名不能为空。",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "无效名称，'\\', '/', '<', '>', ':', '\"', '|', '?' 和 '*' 不被允许使用。",
"Align Left" => "左对齐",
"Alignment" => "对齐",
"Align Right" => "右对齐",
"Annotate" => "注释",
"Background" => "背景",
"Bold" => "粗体",
"Bottom" => "底部",
"Cancel" => "取消",
"Center" => "居中",
"Clone" => "克隆",
"Clone this Style" => "复制此样式",
"Close" => "关闭",
"Color" => "颜色",
"Create" => "创建",
"Decrease Indent" => "减少缩进",
"Default Style" => "默认样式",
"Delete" => "删除",
"Family" => "字体族",
"Font" => "字体",
"Font Effects" => "字体效果",
"Format" => "格式",
"Increase Indent" => "增加缩进",
"Insert Image" => "插入图片",
"Invite Members" => "邀请用户",
"Italic" => "斜体",
"Justified" => "两端对齐",
"Justify" => "对齐",
"Left" => "左对齐",
"Loading" => "加载中",
"Members" => "成员",
"New Name:" => "新样式名称：",
"OK" => "确定",
"Open" => "打开",
"Options" => "选项",
"Paragraph..." => "段落....",
"Paragraph Styles" => "段落样式",
"Redo" => "重做",
"Right" => "右对齐",
"Size" => "大小",
"Spacing" => "边距",
"Strikethrough" => "删除线",
"Style" => "样式",
"Text" => "文本",
"Top" => "顶部",
"Underline" => "下划线",
"Undo" => "撤消",
"Unknown Author" => "未知作者",
"Shared" => "已共享",
"Error" => "错误",
"Error while sharing" => "共享时出错",
"Error while unsharing" => "取消共享时出错",
"Error while changing permissions" => "修改权限时出错",
"Shared with you and the group {group} by {owner}" => "{owner} 共享给您及 {group} 组",
"Shared with you by {owner}" => "{owner} 与您共享",
"Share with users or groups …" => "分享给其他用户或组 ...",
"Share with users, groups or remote users …" => "分享给其他用户、组或远程用户 ...",
"Share" => "共享",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "使用语法 username@example.com/owncloud 分享给其他 ownCloud 上的用户",
"Share link" => "分享链接",
"The public link will expire no later than {days} days after it is created" => "这个共享链接将在创建后 {days} 天失效",
"Link" => "链接",
"Password protect" => "密码保护",
"Password" => "密码",
"Choose a password for the public link" => "为共享链接设置密码",
"Allow editing" => "允许编辑",
"Email link to person" => "发送链接到个人",
"Send" => "发送",
"Set expiration date" => "设置过期日期",
"Expiration" => "过期",
"Expiration date" => "过期日期",
"An error occured. Please try again" => "发生了一个错误请重新尝试",
"Adding user..." => "添加用户中...",
"group" => "群组",
"remote" => "远程",
"Resharing is not allowed" => "不允许二次共享",
"Shared in {item} with {user}" => "在 {item} 与 {user} 共享。",
"Unshare" => "取消共享",
"notify by email" => "以邮件通知",
"can share" => "可共享",
"can edit" => "可编辑",
"access control" => "访问控制",
"create" => "创建",
"change" => "更改",
"delete" => "删除",
"Password protected" => "密码已受保护",
"Error unsetting expiration date" => "取消设置过期日期时出错",
"Error setting expiration date" => "设置过期日期时出错",
"Sending ..." => "正在发送...",
"Email sent" => "邮件已发送",
"Warning" => "警告",
"Edit" => "编辑",
"guest" => "访客",
"MS Word support (requires openOffice/libreOffice)" => "Microsoft Word 支持 (需要 openOffice/libreOffice)",
"Local" => "本地",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "此服务器已经安装 openOffice/libreOffice，config.php 中的 preview_libreoffice_path 指定了程序的路径",
"External" => "外部",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice 安装在一台运行有 Format Filter Server 的外部服务器上",
"Disabled" => "禁用",
"No MS Word support" => "无 MS Word 支持",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "服务器 URL",
"Apply and test" => "应用并测试",
"New document" => "新建文档",
"Upload (max. %s)" => "上传 (最大 %s)",
"Upload" => "上传",
"Save new documents to" => "保存新文档到",
"Wrong password. Please retry." => "密码错误，请重新尝试。",
"Guest %s" => "访客 %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "该链接已失效或不存在。详情请联系文件分享者。",
"Advanced feature-set" => "高级功能",
"(Unstable)" => "(非稳定)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
